==> haskell-prettyprinter-ansi-terminal-1.1.3-464.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-ansi-terminal
version:              1.1.3
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.3-LcajTeMLJmqJgHikO6kzwA
key:                  prettyprinter-ansi-terminal-1.1.3-LcajTeMLJmqJgHikO6kzwA
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  e380a8467189695d27d3be9287945ce6
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-ansi-terminal
hs-libraries:         HSprettyprinter-ansi-terminal-1.1.3-LcajTeMLJmqJgHikO6kzwA
depends:
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt base-4.18.2.1
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.3-468-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-ansi-terminal
version:              1.1.3
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.3-8bIrDelGjXzHJngnsc4lAf
key:                  prettyprinter-ansi-terminal-1.1.3-8bIrDelGjXzHJngnsc4lAf
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  bc08e6599450c2473a36eb709a19f337
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-ansi-terminal-1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-ansi-terminal
hs-libraries:         HSprettyprinter-ansi-terminal-1.1.3-8bIrDelGjXzHJngnsc4lAf
depends:
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh base-4.18.2.1
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
